# Generated by Django 3.0.5 on 2020-05-06 21:18

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('appel_crises', '0019_auto_20200505_2313'),
    ]

    operations = [
        migrations.CreateModel(
            name='BlackListedEmail',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('email', models.EmailField(db_index=True, max_length=254, unique=True)),
            ],
        ),
    ]
